@@ -134,7 +134,7 @@ public class O365Authenticator implements ExchangeAuthenticator {
             String code;
             if (federationRedirectUrl != null && !federationRedirectUrl.isEmpty()) {
                 LOGGER.debug("Detected ADFS, redirecting to " + federationRedirectUrl);
-                code = authenticateADFS(httpClient, federationRedirectUrl);
+                code = authenticateADFS(httpClient, federationRedirectUrl, url);
             } else {
                 PostMethod logonMethod = new PostMethod("https://login.microsoftonline.com/common/login");
                 logonMethod.setRequestHeader("Accept", "text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8");
@@ -162,8 +162,8 @@ public class O365Authenticator implements ExchangeAuthenticator {
                     if (locationHeader == null || !locationHeader.getValue().startsWith(redirectUri)) {
                         // extract response
                         config = extractConfig(logonMethod.getResponseBodyAsString());
-                        if (config.optJSONArray("arrScopes") != null) {
-                            LOGGER.debug("Authentication successful but user consent needed, please open the following url in a browser");
+                        if (config.optJSONArray("arrScopes") != null || config.optJSONArray("urlPostRedirect") != null) {
+                            LOGGER.debug("Authentication successful but user consent or validation needed, please open the following url in a browser");
                             LOGGER.debug(url);
                             throw new DavMailAuthenticationException("EXCEPTION_AUTHENTICATION_FAILED");
                         } else if ("50126".equals(config.optString("sErrorCode"))) {
@@ -199,7 +199,10 @@ public class O365Authenticator implements ExchangeAuthenticator {
 
     }
 
-    private String authenticateADFS(HttpClient httpClient, String federationRedirectUrl) throws IOException {
+    private String authenticateADFS(HttpClient httpClient, String federationRedirectUrl, String authorizeUrl) throws IOException {
+        // set NTLM credentials
+        DavGatewayHttpClientFacade.setCredentials(httpClient, userid, password);
+        DavGatewayHttpClientFacade.addNTLM(httpClient);
         String responseBodyAsString;
 
         // get ADFS login form
@@ -212,30 +215,36 @@ public class O365Authenticator implements ExchangeAuthenticator {
             logonFormMethod.releaseConnection();
         }
 
-        // parse form to get target url, authenticate as userid
-        PostMethod logonMethod = new PostMethod(extract("method=\"post\" action=\"([^\"]+)\"", responseBodyAsString));
-        logonMethod.setRequestHeader("Content-Type", "application/x-www-form-urlencoded");
+        String location;
 
-        logonMethod.setParameter("UserName", userid);
-        logonMethod.setParameter("Password", password);
-        logonMethod.setParameter("AuthMethod", "FormsAuthentication");
+        if (responseBodyAsString.contains("login.microsoftonline.com")) {
+            LOGGER.info("Already authenticated through Basic or NTLM");
+        } else {
+            // parse form to get target url, authenticate as userid
+            PostMethod logonMethod = new PostMethod(extract("method=\"post\" action=\"([^\"]+)\"", responseBodyAsString));
+            logonMethod.setRequestHeader("Content-Type", "application/x-www-form-urlencoded");
 
-        try {
-            httpClient.executeMethod(logonMethod);
-        } finally {
-            logonMethod.releaseConnection();
-        }
+            logonMethod.setParameter("UserName", userid);
+            logonMethod.setParameter("Password", password);
+            logonMethod.setParameter("AuthMethod", "FormsAuthentication");
 
-        if (logonMethod.getStatusCode() != HttpStatus.SC_MOVED_TEMPORARILY || logonMethod.getResponseHeader("Location") == null) {
-            throw new DavMailAuthenticationException("EXCEPTION_AUTHENTICATION_FAILED");
-        }
+            try {
+                httpClient.executeMethod(logonMethod);
+            } finally {
+                logonMethod.releaseConnection();
+            }
 
-        GetMethod redirectMethod = new GetMethod(logonMethod.getResponseHeader("Location").getValue());
-        try {
-            httpClient.executeMethod(redirectMethod);
-            responseBodyAsString = redirectMethod.getResponseBodyAsString();
-        } finally {
-            redirectMethod.releaseConnection();
+            if (logonMethod.getStatusCode() != HttpStatus.SC_MOVED_TEMPORARILY || logonMethod.getResponseHeader("Location") == null) {
+                throw new DavMailAuthenticationException("EXCEPTION_AUTHENTICATION_FAILED");
+            }
+            location = logonMethod.getResponseHeader("Location").getValue();
+            GetMethod redirectMethod = new GetMethod(location);
+            try {
+                httpClient.executeMethod(redirectMethod);
+                responseBodyAsString = redirectMethod.getResponseBodyAsString();
+            } finally {
+                redirectMethod.releaseConnection();
+            }
         }
 
         if (!responseBodyAsString.contains("login.microsoftonline.com")) {
@@ -258,7 +267,7 @@ public class O365Authenticator implements ExchangeAuthenticator {
         targetMethod.setParameter("wctx", wctx);
         try {
             httpClient.executeMethod(targetMethod);
-            responseBodyAsString = logonMethod.getResponseBodyAsString();
+            responseBodyAsString = targetMethod.getResponseBodyAsString();
         } finally {
             targetMethod.releaseConnection();
         }
@@ -267,7 +276,24 @@ public class O365Authenticator implements ExchangeAuthenticator {
         LOGGER.debug(targetMethod.getStatusLine());
         LOGGER.debug(responseBodyAsString);
 
-        throw new IOException("ADFS authentication not yet implemented");
+        if (targetMethod.getStatusCode() == HttpStatus.SC_OK) {
+            JSONObject config = extractConfig(responseBodyAsString);
+            if (config.optJSONArray("arrScopes") != null || config.optJSONArray("urlPostRedirect") != null) {
+                LOGGER.debug("Authentication successful but user consent or validation needed, please open the following url in a browser");
+                LOGGER.debug(authorizeUrl);
+                throw new DavMailAuthenticationException("EXCEPTION_AUTHENTICATION_FAILED");
+            }
+        } else if (targetMethod.getStatusCode() != HttpStatus.SC_MOVED_TEMPORARILY || targetMethod.getRequestHeader("Location") == null) {
+            throw new IOException("Unknown ADFS authentication failure");
+        }
+
+        location = targetMethod.getRequestHeader("Location").getValue();
+        if (location.contains("code=") && location.contains("&session_state=")) {
+            String code = location.substring(location.indexOf("code=") + 5, location.indexOf("&session_state="));
+            LOGGER.debug("Authentication Code: " + code);
+            return code;
+        }
+        throw new IOException("Unknown ADFS authentication failure");
     }
 
     private PostMethod handleMfa(HttpClient httpClient, PostMethod logonMethod, String username, String clientRequestId) throws JSONException, IOException {
