@@ -19,6 +19,7 @@
 
 package davmail.exchange.auth;
 
+import davmail.Settings;
 import davmail.http.DavGatewayHttpClientFacade;
 import davmail.http.RestMethod;
 import davmail.util.IOUtil;
@@ -32,7 +33,8 @@ import java.io.IOException;
 import java.util.Date;
 
 public class O365Token {
-    protected final String URL = "https://login.microsoftonline.com/common/oauth2/token";
+    protected final String TOKEN_URL = "https://login.microsoftonline.com/common/oauth2/token";
+    protected final String RESOURCE_URL = "https://outlook.office365.com/";
 
     protected static final Logger LOGGER = Logger.getLogger(O365Token.class);
 
@@ -43,11 +45,16 @@ public class O365Token {
     private String accessToken;
     private long expireson;
 
+    public O365Token(String clientId, String redirectUri) {
+        this.clientId = clientId;
+        this.redirectUri = redirectUri;
+    }
+
     public O365Token(String clientId, String redirectUri, String code) throws IOException {
         this.clientId = clientId;
         this.redirectUri = redirectUri;
 
-        RestMethod tokenMethod = new RestMethod(URL);
+        RestMethod tokenMethod = new RestMethod(TOKEN_URL);
         tokenMethod.setRequestHeader("Content-Type", "application/x-www-form-urlencoded");
         tokenMethod.addParameter("grant_type", "authorization_code");
         tokenMethod.addParameter("code", code);
@@ -64,6 +71,9 @@ public class O365Token {
 
     public void setJsonToken(JSONObject jsonToken) throws IOException {
         try {
+            if (jsonToken.opt("error") != null) {
+                throw new IOException(jsonToken.optString("error")+" "+jsonToken.optString("error_description"));
+            }
             // access token expires after one hour
             accessToken = jsonToken.getString("access_token");
             // precious refresh token
@@ -77,6 +87,11 @@ public class O365Token {
             JSONObject tokenBody = new JSONObject(decodedBearer);
             LOGGER.debug("Token: " + tokenBody);
             username = tokenBody.getString("unique_name");
+
+            if (Settings.getBooleanProperty("davmail.oauth.persistToken", false)) {
+                Settings.setProperty("davmail.oauth."+username.toLowerCase()+".refreshToken", refreshToken);
+                Settings.save();
+            }
         } catch (JSONException e) {
             throw new IOException("Exception parsing token", e);
         }
@@ -102,16 +117,18 @@ public class O365Token {
 
     public void setAccessToken(String accessToken) {
         this.accessToken = accessToken;
+        // assume unexpired token
+        expireson = System.currentTimeMillis() + 1000 * 60 * 60;
     }
 
-    private void refreshToken() throws IOException {
-        String url = "https://login.microsoftonline.com/common/oauth2/token";
-        RestMethod tokenMethod = new RestMethod(url);
+    public void refreshToken() throws IOException {
+        RestMethod tokenMethod = new RestMethod(TOKEN_URL);
         tokenMethod.setRequestHeader("Content-Type", "application/x-www-form-urlencoded");
         tokenMethod.addParameter("grant_type", "refresh_token");
         tokenMethod.addParameter("refresh_token", refreshToken);
         tokenMethod.addParameter("redirect_uri", redirectUri);
         tokenMethod.addParameter("client_id", clientId);
+        tokenMethod.addParameter("resource", "https://outlook.office365.com/");
 
         executeMethod(tokenMethod);
     }
@@ -119,7 +136,7 @@ public class O365Token {
     private void executeMethod(RestMethod tokenMethod) throws IOException {
         HttpClient httpClient = null;
         try {
-            httpClient = DavGatewayHttpClientFacade.getInstance(URL);
+            httpClient = DavGatewayHttpClientFacade.getInstance(RESOURCE_URL);
             httpClient.executeMethod(tokenMethod);
             setJsonToken(tokenMethod.getJsonResponse());
 
@@ -132,4 +149,8 @@ public class O365Token {
         }
 
     }
+
+    public void setRefreshToken(String refreshToken) {
+        this.refreshToken = refreshToken;
+    }
 }
