@@ -545,6 +545,7 @@ public abstract class EWSMethod extends PostMethod {
         protected List<Attendee> attendees;
         protected final List<String> fieldNames = new ArrayList<String>();
         protected List<Occurrence> occurrences;
+        protected List<String> members;
         protected ItemId referenceItemId;
 
         @Override
@@ -733,6 +734,27 @@ public abstract class EWSMethod extends PostMethod {
         public List<Occurrence> getOccurrences() {
             return occurrences;
         }
+
+        /**
+         * Add member.
+         *
+         * @param member list member
+         */
+        public void addMember(String member) {
+            if (members == null) {
+                members = new ArrayList<String>();
+            }
+            members.add(member);
+        }
+
+        /**
+         * Get members.
+         *
+         * @return event members
+         */
+        public List<String> getMembers() {
+            return members;
+        }
     }
 
     /**
@@ -751,7 +773,10 @@ public abstract class EWSMethod extends PostMethod {
                     && !"ErrorCalendarOccurrenceIsDeletedFromRecurrence".equals(errorDetail)
                     ) {
                 try {
-                    throw new EWSException(errorDetail + ' ' + ((errorDescription != null) ? errorDescription : "") + "\n request: " + new String(generateSoapEnvelope(), "UTF-8"));
+                    throw new EWSException(errorDetail
+                            + ' ' + ((errorDescription != null) ? errorDescription : "")
+                            + ' ' + ((errorValue != null) ? errorValue : "")
+                            + "\n request: " + new String(generateSoapEnvelope(), "UTF-8"));
                 } catch (UnsupportedEncodingException e) {
                     throw new EWSException(e.getMessage());
                 }
@@ -820,18 +845,30 @@ public abstract class EWSMethod extends PostMethod {
     }
 
     protected String handleTag(XMLStreamReader reader, String localName) throws XMLStreamException {
-        String result = null;
+        StringBuilder result = null;
         int event = reader.getEventType();
         if (event == XMLStreamConstants.START_ELEMENT && localName.equals(reader.getLocalName())) {
+            result = new StringBuilder();
             while (reader.hasNext() &&
                     !((event == XMLStreamConstants.END_ELEMENT && localName.equals(reader.getLocalName())))) {
                 event = reader.next();
                 if (event == XMLStreamConstants.CHARACTERS) {
-                    result = reader.getText();
+                    result.append(reader.getText());
+                } else if ("MessageXml".equals(localName) && event == XMLStreamConstants.START_ELEMENT) {
+                    for (int i = 0;i<reader.getAttributeCount();i++) {
+                        if (result.length() > 0) {
+                            result.append(", ");
+                        }
+                        result.append(reader.getAttributeLocalName(i)).append(": ").append(reader.getAttributeValue(i));
+                    }
                 }
             }
         }
-        return result;
+        if (result != null && result.length() > 0) {
+            return result.toString();
+        } else {
+            return null;
+        }
     }
 
     protected void handleErrors(XMLStreamReader reader) throws XMLStreamException {
@@ -869,6 +906,8 @@ public abstract class EWSMethod extends PostMethod {
                 String value = null;
                 if ("ExtendedProperty".equals(tagLocalName)) {
                     addExtendedPropertyValue(reader, responseItem);
+                } else if ("Members".equals(tagLocalName)) {
+                    handleMembers(reader, responseItem);
                 } else if (tagLocalName.endsWith("MimeContent")) {
                     handleMimeContent(reader, responseItem);
                 } else if ("Attachments".equals(tagLocalName)) {
@@ -950,6 +989,34 @@ public abstract class EWSMethod extends PostMethod {
         item.addOccurrence(occurrence);
     }
 
+    protected void handleMembers(XMLStreamReader reader, Item responseItem) throws XMLStreamException {
+        while (reader.hasNext() && !XMLStreamUtil.isEndTag(reader, "Members")) {
+            reader.next();
+            if (XMLStreamUtil.isStartTag(reader)) {
+                String tagLocalName = reader.getLocalName();
+                if ("Member".equals(tagLocalName)) {
+                    handleMember(reader, responseItem);
+                }
+            }
+        }
+    }
+
+    protected void handleMember(XMLStreamReader reader, Item responseItem) throws XMLStreamException {
+        String member = null;
+        while (reader.hasNext() && !XMLStreamUtil.isEndTag(reader, "Member")) {
+            reader.next();
+            if (XMLStreamUtil.isStartTag(reader)) {
+                String tagLocalName = reader.getLocalName();
+                if ("EmailAddress".equals(tagLocalName) && member == null) {
+                    member = "mailto:"+XMLStreamUtil.getElementText(reader);
+                }
+            }
+        }
+        if (member != null) {
+            responseItem.addMember(member);
+        }
+    }
+
     /**
      * Convert response type to partstat value
      *
@@ -1139,6 +1206,9 @@ public abstract class EWSMethod extends PostMethod {
                         DavGatewayTray.switchIcon();
                         lastLogCount = totalCount;
                     }
+                    /*if (count > 0 && LOGGER.isDebugEnabled()) {
+                        LOGGER.debug(new String(buffer, offset, count, "UTF-8"));
+                    }*/
                     return count;
                 }
             };
