@@ -268,6 +268,8 @@ public class SettingsFrame extends JFrame {
             isJavaFXAvailable = true;
         } catch (ClassNotFoundException e) {
             // ignore
+        } catch (NoClassDefFoundError e) {
+            // ignore
         }
         return isJavaFXAvailable;
     }
@@ -902,10 +904,7 @@ public class SettingsFrame extends JFrame {
         pack();
         //setResizable(false);
         // center frame
-        setLocation(getToolkit().getScreenSize().width / 2 -
-                getSize().width / 2,
-                getToolkit().getScreenSize().height / 2 -
-                        getSize().height / 2);
+        setLocationRelativeTo(null);
         urlField.requestFocus();
     }
 }
