@@ -32,9 +32,12 @@ import org.apache.log4j.lf5.viewer.LogBrokerMonitor;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.events.DisposeEvent;
 import org.eclipse.swt.events.DisposeListener;
+import org.eclipse.swt.graphics.DeviceData;
+import org.eclipse.swt.graphics.GC;
 import org.eclipse.swt.graphics.Image;
-import org.eclipse.swt.internal.gtk.GdkRectangle;
-import org.eclipse.swt.internal.gtk.OS;
+import org.eclipse.swt.graphics.ImageData;
+import org.eclipse.swt.internal.gtk.GDK;
+import org.eclipse.swt.internal.gtk.GTK;
 import org.eclipse.swt.widgets.*;
 
 import javax.swing.*;
@@ -47,6 +50,8 @@ import java.util.ArrayList;
  * Tray icon handler based on SWT
  */
 public class SwtGatewayTray implements DavGatewayTrayInterface {
+    private static final Logger LOGGER = Logger.getLogger(SwtGatewayTray.class);
+
     protected SwtGatewayTray() {
     }
 
@@ -184,7 +189,16 @@ public class SwtGatewayTray implements DavGatewayTrayInterface {
                 throw new IOException(fileName);
             }
             byte[] imageContent = IOUtil.readFully(imageUrl.openStream());
-            result = new Image(display, new ByteArrayInputStream(imageContent));
+            Image tempImage = new Image(display, new ByteArrayInputStream(imageContent));
+            Image backgroundImage = new Image(null, 24, 24);
+            ImageData imageData = backgroundImage.getImageData();
+            imageData.transparentPixel = imageData.getPixel(0, 0);
+            backgroundImage.dispose();
+            result = new Image(null, imageData);
+
+            GC gc = new GC(result);
+            gc.drawImage(tempImage, 4, 4);
+            tempImage.dispose();
 
         } catch (IOException e) {
             DavGatewayTray.warn(new BundleMessage("LOG_UNABLE_TO_LOAD_IMAGE"), e);
@@ -196,20 +210,13 @@ public class SwtGatewayTray implements DavGatewayTrayInterface {
      * Create tray icon and register frame listeners.
      */
     public void init() {
-        // register error handler to avoid application crash on concurrent X access from SWT and AWT
-        try {
-            OS.gdk_error_trap_push();
-        } catch (NoClassDefFoundError e) {
-            // ignore
+        if (GTK.GTK3) {
+            throw new RuntimeException("GTK 3 not supported, please set SWT_GTK=0");
         }
-        final String systemLookAndFeelClassName = UIManager.getSystemLookAndFeelClassName();
+        GDK.gdk_error_trap_push();
         try {
             // workaround for bug when SWT and AWT both try to access Gtk
-            if (systemLookAndFeelClassName.contains("gtk")) {
-                System.setProperty("swing.defaultlaf", UIManager.getCrossPlatformLookAndFeelClassName());
-            } else {
-                System.setProperty("swing.defaultlaf", systemLookAndFeelClassName);
-            }
+            UIManager.setLookAndFeel(UIManager.getCrossPlatformLookAndFeelClassName());
         } catch (Exception e) {
             DavGatewayTray.warn(new BundleMessage("LOG_UNABLE_TO_SET_LOOK_AND_FEEL"));
         }
@@ -218,7 +225,9 @@ public class SwtGatewayTray implements DavGatewayTrayInterface {
             @Override
             public void run() {
                 try {
-                    display = new Display();
+                    DeviceData data = new DeviceData();
+                    data.debug = true;
+                    display = new Display(data);
                     shell = new Shell(display);
 
                     final Tray tray = display.getSystemTray();
@@ -227,17 +236,6 @@ public class SwtGatewayTray implements DavGatewayTrayInterface {
                         trayItem = new TrayItem(tray, SWT.NONE);
                         trayItem.setToolTipText(BundleMessage.format("UI_DAVMAIL_GATEWAY"));
 
-                        // Under Unity, check if tray is indeed available
-                        if (systemLookAndFeelClassName.contains("gtk") &&
-                                "Unity".equals(System.getenv("XDG_CURRENT_DESKTOP"))) {
-                            GdkRectangle area = new GdkRectangle();
-                            OS.gtk_status_icon_get_geometry(trayItem.handle, 0, area, 0);
-
-                            if (area.x == 0 && area.y == 0) {
-                                throw new Error("System tray not available");
-                            }
-                        }
-
                         frameIcons = new ArrayList<java.awt.Image>();
                         frameIcons.add(DavGatewayTray.loadImage(AwtGatewayTray.TRAY128_PNG));
                         frameIcons.add(DavGatewayTray.loadImage(AwtGatewayTray.TRAY_PNG));
@@ -278,7 +276,7 @@ public class SwtGatewayTray implements DavGatewayTrayInterface {
                         aboutItem.setText(BundleMessage.format("UI_ABOUT"));
                         aboutItem.addListener(SWT.Selection, new Listener() {
                             public void handleEvent(Event event) {
-                                display.asyncExec(
+                                SwingUtilities.invokeLater(
                                         new Runnable() {
                                             public void run() {
                                                 if (aboutFrame == null) {
@@ -293,9 +291,10 @@ public class SwtGatewayTray implements DavGatewayTrayInterface {
                             }
                         });
 
+                        // create menu item for the default action
                         trayItem.addListener(SWT.DefaultSelection, new Listener() {
                             public void handleEvent(Event event) {
-                                display.asyncExec(
+                                SwingUtilities.invokeLater(
                                         new Runnable() {
                                             public void run() {
                                                 // create frame on first call
@@ -311,12 +310,11 @@ public class SwtGatewayTray implements DavGatewayTrayInterface {
                             }
                         });
 
-                        // create menu item for the default action
                         MenuItem defaultItem = new MenuItem(popup, SWT.PUSH);
                         defaultItem.setText(BundleMessage.format("UI_SETTINGS"));
                         defaultItem.addListener(SWT.Selection, new Listener() {
                             public void handleEvent(Event event) {
-                                display.asyncExec(
+                                SwingUtilities.invokeLater(
                                         new Runnable() {
                                             public void run() {
                                                 // create frame on first call
@@ -336,7 +334,7 @@ public class SwtGatewayTray implements DavGatewayTrayInterface {
                         logItem.setText(BundleMessage.format("UI_SHOW_LOGS"));
                         logItem.addListener(SWT.Selection, new Listener() {
                             public void handleEvent(Event event) {
-                                display.asyncExec(
+                                SwingUtilities.invokeLater(
                                         new Runnable() {
                                             public void run() {
 
@@ -369,13 +367,19 @@ public class SwtGatewayTray implements DavGatewayTrayInterface {
 
                         // display settings frame on first start
                         if (Settings.isFirstStart()) {
-                            // create frame on first call
-                            if (settingsFrame == null) {
-                                settingsFrame = new SettingsFrame();
-                            }
-                            settingsFrame.setVisible(true);
-                            settingsFrame.toFront();
-                            settingsFrame.requestFocus();
+                            SwingUtilities.invokeLater(new Runnable() {
+                                @Override
+                                public void run() {
+                                    // create frame on first call
+                                    if (settingsFrame == null) {
+                                        settingsFrame = new SettingsFrame();
+                                    }
+                                    settingsFrame.setVisible(true);
+                                    settingsFrame.toFront();
+                                    settingsFrame.requestFocus();
+                                }
+                            });
+
                         }
 
                         synchronized (mainThread) {
